
Contributing to PyDeseq2
========================

Please check out the current version of the contributing guidelines in:
`docs/source/usage/contributing.rst`, or in the `PyDeseq2` Documentation at:

https://pydeseq2.readthedocs.io/en/latest/usage/contributing.html

Code of Conduct
---------------

`PyDeseq2` follows the code of conduct defined by
the Python Software Foundation: https://www.python.org/psf/codeofconduct/.
